@@ -13,13 +13,14 @@ import time
 from functools import partial
 
 from bypy.constants import (
-    OUTPUT_DIR, PREFIX, SRC as CALIBRE_DIR, python_major_minor_version
+    OUTPUT_DIR, PREFIX, SRC as CALIBRE_DIR, python_major_minor_version,
 )
 from bypy.freeze import (
-    extract_extension_modules, fix_pycryptodome, freeze_python, path_to_freeze_dir
+    extract_extension_modules, fix_pycryptodome, freeze_python, is_package_dir,
+    path_to_freeze_dir,
 )
 from bypy.utils import (
-    create_job, get_dll_path, mkdtemp, parallel_build, py_compile, run, walk
+    create_job, get_dll_path, mkdtemp, parallel_build, py_compile, run, walk,
 )
 
 j = os.path.join
@@ -44,7 +45,7 @@ def binary_includes():
         ] + list(map(
             get_dll_path,
             ('usb-1.0 mtp expat sqlite3 ffi z lzma openjp2 poppler dbus-1 iconv xml2 xslt jpeg png16'
-             ' webp webpmux webpdemux exslt ncursesw readline chm hunspell-1.7 hyphen'
+             ' webp webpmux webpdemux sharpyuv exslt ncursesw readline chm hunspell-1.7 hyphen'
              ' icudata icui18n icuuc icuio stemmer gcrypt gpg-error uchardet graphite2'
              ' brotlicommon brotlidec brotlienc zstd podofo'
              ' gobject-2.0 glib-2.0 gthread-2.0 gmodule-2.0 gio-2.0 dbus-glib-1').split()
@@ -90,9 +91,8 @@ def ignore_in_lib(base, items, ignored_dirs=None):
     for name in items:
         path = j(base, name)
         if os.path.isdir(path):
-            if name in ignored_dirs or not os.path.exists(j(path, '__init__.py')):
-                if name != 'plugins':
-                    ans.append(name)
+            if name != 'plugins' and (name in ignored_dirs or not is_package_dir(path)):
+                ans.append(name)
         else:
             if name.rpartition('.')[-1] not in ('so', 'py'):
                 ans.append(name)
@@ -112,7 +112,7 @@ def import_site_packages(srcdir, dest):
                 src = os.path.abspath(j(srcdir, line))
                 if os.path.exists(src) and os.path.isdir(src):
                     import_site_packages(src, dest)
-        elif os.path.exists(j(f, '__init__.py')):
+        elif is_package_dir(f):
             shutil.copytree(f, j(dest, x), ignore=ignore_in_lib)
 
 
